/*
 * theme.h: Theme implementation
 *
 * See the main source file 'vdr.c' for copyright information and
 * how to reach the author.
 *
 * 
 */

#ifndef __THEME_H
#define __THEME_H

#include "interface.h"
#include "config.h"

enum eOSDTheme {
  themeVanilla,
  themeElchi,
  themeSaschaScroll,
  themeSaschaRound
};

#define MODE_PLAY   0
#define MODE_FFWD1  1
#define MODE_FFWD2  2
#define MODE_FFWD3  3
#define MODE_PAUSE  4
#define MODE_REW1   5
#define MODE_REW2   6
#define MODE_REW3   7
#define MODE_FFWD   8
#define MODE_REW    9
#define MODE_SFWD1 10
#define MODE_SFWD2 11
#define MODE_SFWD3 12
#define MODE_SREW1 13
#define MODE_SREW2 14
#define MODE_SREW3 15
#define MODE_SFWD  16
#define MODE_SREW  17

#define FSYM_THINSPACE        32 /* " " */

#define FSYM_DDIGITAL         33 /* "!" */
#define FSYM_TELETEXT         34 /* """ */
#define FSYM_ENCRYPTION       35 /* "#" */
#define FSYM_AUDIO            36 /* "$" */
#define FSYM_RECORD           37 /* "%" */
#define FSYM_MUSIC            38 /* "&" */

#define FSYM_WAVE_UP1         41 /* ")" */
#define FSYM_WAVE_UP2         42 /* "*" */
#define FSYM_WAVE_DOWN1       43 /* "+" */
#define FSYM_WAVE_DOWN2       44 /* "," */
#define FSYM_ROUND_LEFT1      45 /* "-" */
#define FSYM_ROUND_LEFT2      46 /* "." */
#define FSYM_ROUND_RIGHT1     47 /* "/" */
#define FSYM_ROUND_RIGHT2     48 /* "0" */
#define FSYM_ROUND_LEFT       49 /* "1" */
#define FSYM_ROUND_RIGHT      50 /* "2" */
#define FSYM_THINROUND_RIGHT  51 /* "3" */
#define FSYM_THINROUND_RIGHT1 52 /* "4" */
#define FSYM_THINROUND_RIGHT2 53 /* "5" */
#define FSYM_TRIANGLE         54 /* "6" */

#define FSYM_PLAY             57 /* "9" */
#define FSYM_FFWD1            58 /* ":" */
#define FSYM_FFWD2            59 /* ";" */
#define FSYM_FFWD3            60 /* "<" */
#define FSYM_PAUSE            61 /* "=" */
#define FSYM_REW1             62 /* ">" */
#define FSYM_REW2             63 /* "?" */
#define FSYM_REW3             64 /* "@" */
#define FSYM_EMPTY            65 /* "A" */
#define FSYM_FFWD             66 /* "B" */
#define FSYM_REW              67 /* "C" */

#define FSYM_PLAY_SMALL       70 /* "F" */
#define FSYM_FFWD1_SMALL      71 /* "G" */
#define FSYM_FFWD2_SMALL      72 /* "H" */
#define FSYM_FFWD3_SMALL      73 /* "I" */
#define FSYM_PAUSE_SMALL      74 /* "J" */
#define FSYM_REW1_SMALL       75 /* "K" */
#define FSYM_REW2_SMALL       76 /* "L" */
#define FSYM_REW3_SMALL       77 /* "M" */
#define FSYM_EMPTY_SMALL      78 /* "N" */
#define FSYM_FFWD_SMALL       79 /* "O" */
#define FSYM_REW_SMALL        80 /* "P" */

#define FSYM_SFWD1            83 /* "S" */
#define FSYM_SFWD2            84 /* "T" */
#define FSYM_SFWD3            85 /* "U" */
#define FSYM_SREW1            86 /* "V" */
#define FSYM_SREW2            87 /* "W" */
#define FSYM_SREW3            88 /* "X" */
#define FSYM_SFWD             89 /* "Y" */
#define FSYM_SREW             90 /* "Z" */

class cDisplayChannelTheme : public cBitmap {
private:
	int lines;
public:
	cDisplayChannelTheme(void);
	virtual ~cDisplayChannelTheme();
	void Reset(void);
	void DrawChannel(const cChannel *Channel, int Number);
	bool DrawInfo(void);
	static int Width(void) { return Setup.OSDwidth; }
	static int Height(bool WithInfo);
};

class cReplayControlTheme : public cBitmap {
public:
	cReplayControlTheme(void);
	virtual ~cReplayControlTheme();
	void DrawMode(int Mode, bool ModeOnly);
	void DrawProgress(int Current, int Total, bool DisplayFrames,
	const cMarks &Marks, const char *Title);
	static int Width(void) { return Setup.OSDwidth; }
	static int Height(bool WithInfo);
};

#endif // __THEME_H
